%define upstream_name    indirect
%define upstream_version 0.39

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 8

Summary:    Lexically warn about using the indirect method call syntax
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/V/VP/VPIT/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Config)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(IO::Handle)
BuildRequires: perl(IO::Select)
BuildRequires: perl(IPC::Open3)
BuildRequires: perl(POSIX)
BuildRequires: perl(Socket)
BuildRequires: perl(Test::More)
BuildRequires: perl(XSLoader)
BuildRequires: perl(lib)
BuildRequires: perl-devel
Provides:   perl(indirect)

%description
When enabled, this pragma warns about indirect method calls that are
present in your code.

The indirect syntax is now considered harmful, since its parsing has many
quirks and its use is error prone : when the subroutine 'foo' has not been
declared in the current package, 'foo $x' actually compiles to '$x->foo',
and 'foo { key => 1 }' to ''key'->foo(1)'. In the
https://shadowcat.co.uk/blog/matt-s-trout/indirect-but-still-fatal
manpage, Matt S. Trout gives an example of an undesirable indirect method
call on a block that can cause a particularly bewildering error.

This pragma currently does not warn for core functions ('print', 'say',
'exec' or 'system'). This may change in the future, or may be added as
optional features that would be enabled by passing options to 'unimport'.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes META.json META.yml MYMETA.yml README samples
%{_mandir}/man3/*
%{perl_vendorarch}/*


%changelog
* Tue Nov 28 2023 tv <tv> 0.390.0-8.mga10
+ Revision: 2010946
- Rebuild for perl-5.38

* Tue Jun 07 2022 umeabot <umeabot> 0.390.0-7.mga9
+ Revision: 1862878
- Rebuild for Perl 5.36

* Thu Mar 17 2022 umeabot <umeabot> 0.390.0-6.mga9
+ Revision: 1796246
- Mageia 9 Mass Rebuild

* Mon May 24 2021 umeabot <umeabot> 0.390.0-5.mga9
+ Revision: 1727684
- Rebuild for perl 5.34

* Thu Jun 18 2020 umeabot <umeabot> 0.390.0-4.mga8
+ Revision: 1595654
- Rebuild for perl 5.32

* Sat Feb 15 2020 umeabot <umeabot> 0.390.0-3.mga8
+ Revision: 1529115
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 tv <tv> 0.390.0-2.mga8
+ Revision: 1433132
- rebuild with perl-5.30

* Mon Jul 08 2019 tv <tv> 0.390.0-1.mga8
+ Revision: 1419632
- update to 0.39

* Fri Sep 21 2018 umeabot <umeabot> 0.380.0-3.mga7
+ Revision: 1294082
- Mageia 7 Mass Rebuild

* Wed Aug 08 2018 pterjan <pterjan> 0.380.0-2.mga7
+ Revision: 1249942
- Rebuild for perl 5.28

* Tue Apr 24 2018 tv <tv> 0.380.0-1.mga7
+ Revision: 1222157
- update to 0.38

* Tue Oct 03 2017 tv <tv> 0.370.0-3.mga7
+ Revision: 1164923
- rebuild with fixed rpm for missing autodeps

* Thu Aug 31 2017 pterjan <pterjan> 0.370.0-2.mga7
+ Revision: 1148954
- Rebuild for perl ABI changes

* Sun Jul 23 2017 shlomif <shlomif> 0.370.0-1.mga7
+ Revision: 1129073
- update to 0.37

* Sat Jul 22 2017 neoclust <neoclust> 0.360.0-4.mga7
+ Revision: 1126576
- Rebuild against new Perl 5.26

* Sun Jun 19 2016 pterjan <pterjan> 0.360.0-3.mga6
+ Revision: 1028536
- Rebuild for perl 5.22.2

* Fri Feb 12 2016 umeabot <umeabot> 0.360.0-2.mga6
+ Revision: 957516
- Mageia 6 Mass Rebuild

* Mon Jul 27 2015 sander85 <sander85> 0.360.0-1.mga6
+ Revision: 858262
- update to 0.36

* Fri Jun 26 2015 tv <tv> 0.350.0-2.mga6
+ Revision: 844913
- rebuild for soname-ifed perl

* Tue Jun 23 2015 shlomif <shlomif> 0.350.0-1.mga6
+ Revision: 840515
- New version 0.35 + Rebuild for new perl

* Wed Oct 15 2014 umeabot <umeabot> 0.310.0-6.mga5
+ Revision: 746801
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.310.0-5.mga5
+ Revision: 687031
- Mageia 5 Mass Rebuild

* Tue Jun 03 2014 pterjan <pterjan> 0.310.0-4.mga5
+ Revision: 631929
- Rebuild for perl 5.20

* Tue Feb 25 2014 jquelin <jquelin> 0.310.0-3.mga5
+ Revision: 597038
- missing provides:

* Sat Oct 19 2013 umeabot <umeabot> 0.310.0-2.mga5
+ Revision: 534779
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 sander85 <sander85> 0.310.0-1.mga4
+ Revision: 478847
- update to 0.31

* Wed May 29 2013 jquelin <jquelin> 0.260.0-3.mga4
+ Revision: 431853
- perl 5.18.0 rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.260.0-2.mga3
+ Revision: 375448
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Aug 05 2012 shlomif <shlomif> 0.260.0-1.mga3
+ Revision: 278656
- imported package perl-indirect

